"""Encryption mixins"""

import base64

from cryptography.hazmat.backends import default_backend
from cryptography.hazmat.primitives import hashes
from cryptography.hazmat.primitives.kdf.pbkdf2 import PBKDF2HMAC

from ..constants.encryption import FERNET_PASSPHRASE, SALT


class EncryptionMixin:
    """Encryption mixin"""

    @staticmethod
    def getEncryptionKey(Id: str) -> bytes:
        """Generate encryption key from password"""
        kdf = PBKDF2HMAC(algorithm=hashes.SHA512(), length=32, salt=SALT, iterations=1000, backend=default_backend())
        password = FERNET_PASSPHRASE + Id
        return base64.urlsafe_b64encode(kdf.derive(password.encode()))
